@@ -10,15 +10,15 @@ use strict;
 use warnings;
 our ( %Config, $VERSION );
 
-$VERSION = "5.036003";
+$VERSION = "5.038005";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
 # lifetime of Perl 5.
 my %Export_Cache = (myconfig => 1, config_sh => 1, config_vars => 1,
-		    config_re => 1, compile_date => 1, local_patches => 1,
-		    bincompat_options => 1, non_bincompat_options => 1,
-		    header_files => 1);
+                    config_re => 1, compile_date => 1, local_patches => 1,
+                    bincompat_options => 1, non_bincompat_options => 1,
+                    header_files => 1);
 
 @Config::EXPORT = qw(%Config);
 @Config::EXPORT_OK = keys %Export_Cache;
@@ -47,20 +47,20 @@ sub import {
     no strict 'refs';
     my $callpkg = caller(0);
     foreach my $func (@funcs) {
-	die qq{"$func" is not exported by the Config module\n}
-	    unless $Export_Cache{$func};
-	*{$callpkg.'::'.$func} = \&{$func};
+        die qq{"$func" is not exported by the Config module\n}
+            unless $Export_Cache{$func};
+        *{$callpkg.'::'.$func} = \&{$func};
     }
 
     *{"$callpkg\::Config"} = \%Config if $export_Config;
     return;
 }
 
-die "$0: Perl lib version (5.36.3) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.38.5) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.36.3
-    or die sprintf "%s: Perl lib version (5.36.3) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.38.5
+    or die sprintf "%s: Perl lib version (5.38.5) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -84,7 +84,7 @@ sub AUTOLOAD {
 
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
-    archlibexp => '/opt/local/lib/perl5/5.36/darwin-thread-multi-2level',
+    archlibexp => '/opt/local/lib/perl5/5.38/darwin-thread-multi-2level',
     archname => 'darwin-thread-multi-2level',
     cc => '/usr/bin/cc',
     d_readlink => 'define',
@@ -96,16 +96,16 @@ tie %Config, 'Config', {
     inc_version_list => ' ',
     intsize => '4',
     ldlibpthname => 'DYLD_LIBRARY_PATH',
-    libpth => '/opt/local/lib /usr/bin/../lib/clang/5.1/lib /usr/lib',
+    libpth => '/opt/local/lib /opt/local/libexec/llvm-3.7/bin/../lib/clang/3.7.1/lib /usr/lib',
     osname => 'darwin',
     osvers => '12.6.0',
     path_sep => ':',
-    privlibexp => '/opt/local/lib/perl5/5.36',
+    privlibexp => '/opt/local/lib/perl5/5.38',
     scriptdir => '/opt/local/bin',
-    sitearchexp => '/opt/local/lib/perl5/site_perl/5.36/darwin-thread-multi-2level',
-    sitelibexp => '/opt/local/lib/perl5/site_perl/5.36',
+    sitearchexp => '/opt/local/lib/perl5/site_perl/5.38/darwin-thread-multi-2level',
+    sitelibexp => '/opt/local/lib/perl5/site_perl/5.38',
     so => 'dylib',
     useithreads => 'define',
     usevendorprefix => 'define',
-    version => '5.36.3',
+    version => '5.38.5',
 };
